Struct range_checked::I32Bounded
source · pub struct I32Bounded<const LO: i32, const HI: i32, const INCLUSIVE: bool>(/* private fields */);Expand description
Implements the TryFrom type, which attempts to convert to the contained type, returning an error if the input is out of bounds.
This type also implements [Deref] into the contained type.
Implementations
Methods from Deref<Target = i32>
pub const MIN: i32 = -2_147_483_648i32
pub const MAX: i32 = 2_147_483_647i32
pub const BITS: u32 = 32u32