pub struct I64Bounded<const LO: i64, const HI: i64, const INCLUSIVE: bool>(/* private fields */);
Implements the TryFrom type, which attempts to convert to the contained type, returning an error if the input is out of bounds. This type also implements [Deref] into the contained type.

Implementations

source

impl<const LO: i64, const HI: i64, const INCLUSIVE: bool> I64Bounded<LO, HI, INCLUSIVE>

source

pub const fn from<const LO2: i64, const HI2: i64>( other: I64Bounded<LO2, HI2, INCLUSIVE> ) -> Result<Self, FromError<i64>>

Methods from Deref<Target = i64>

1.43.0 · source

pub const MIN: i64 = -9_223_372_036_854_775_808i64

1.43.0 · source

pub const MAX: i64 = 9_223_372_036_854_775_807i64

1.53.0 · source

pub const BITS: u32 = 64u32