Struct range_checked::I8Bounded
source · pub struct I8Bounded<const LO: i8, const HI: i8, const INCLUSIVE: bool>(/* private fields */);Expand description
Implements the TryFrom type, which attempts to convert to the contained type, returning an error if the input is out of bounds.
This type also implements [Deref] into the contained type.
Implementations
Methods from Deref<Target = i8>
pub const MIN: i8 = -128i8
pub const MAX: i8 = 127i8
pub const BITS: u32 = 8u32