pub struct IsizeBounded<const LO: isize, const HI: isize, const INCLUSIVE: bool>(/* private fields */);
Implements the TryFrom type, which attempts to convert to the contained type, returning an error if the input is out of bounds. This type also implements [Deref] into the contained type.

Implementations

source

impl<const LO: isize, const HI: isize, const INCLUSIVE: bool> IsizeBounded<LO, HI, INCLUSIVE>

source

pub const fn from<const LO2: isize, const HI2: isize>( other: IsizeBounded<LO2, HI2, INCLUSIVE> ) -> Result<Self, FromError<isize>>

Methods from Deref<Target = isize>

1.43.0 · source

pub const MIN: isize = -9_223_372_036_854_775_808isize

1.43.0 · source

pub const MAX: isize = 9_223_372_036_854_775_807isize

1.53.0 · source

pub const BITS: u32 = 64u32