Struct range_checked::U32Bounded
source · pub struct U32Bounded<const LO: u32, const HI: u32, const INCLUSIVE: bool>(/* private fields */);Expand description
Implements the TryFrom type, which attempts to convert to the contained type, returning an error if the input is out of bounds.
This type also implements [Deref] into the contained type.
Implementations
Methods from Deref<Target = u32>
pub const MIN: u32 = 0u32
pub const MAX: u32 = 4_294_967_295u32
pub const BITS: u32 = 32u32