pub struct U64Bounded<const LO: u64, const HI: u64, const INCLUSIVE: bool>(/* private fields */);
Implements the TryFrom type, which attempts to convert to the contained type, returning an error if the input is out of bounds. This type also implements [Deref] into the contained type.

Implementations

source

impl<const LO: u64, const HI: u64, const INCLUSIVE: bool> U64Bounded<LO, HI, INCLUSIVE>

source

pub const fn from<const LO2: u64, const HI2: u64>( other: U64Bounded<LO2, HI2, INCLUSIVE> ) -> Result<Self, FromError<u64>>

Methods from Deref<Target = u64>

1.43.0 · source

pub const MIN: u64 = 0u64

1.43.0 · source

pub const MAX: u64 = 18_446_744_073_709_551_615u64

1.53.0 · source

pub const BITS: u32 = 64u32