Struct range_checked::I64Bounded
source · pub struct I64Bounded<const LO: i64, const HI: i64, const INCLUSIVE: bool>(/* private fields */);Expand description
Implements the TryFrom type, which attempts to convert to the contained type, returning an error if the input is out of bounds.
This type also implements [Deref] into the contained type.
Implementations
Methods from Deref<Target = i64>
pub const MIN: i64 = -9_223_372_036_854_775_808i64
pub const MAX: i64 = 9_223_372_036_854_775_807i64
pub const BITS: u32 = 64u32