Struct range_checked::U64Bounded
source · pub struct U64Bounded<const LO: u64, const HI: u64, const INCLUSIVE: bool>(/* private fields */);Expand description
Implements the TryFrom type, which attempts to convert to the contained type, returning an error if the input is out of bounds.
This type also implements [Deref] into the contained type.
Implementations
Methods from Deref<Target = u64>
pub const MIN: u64 = 0u64
pub const MAX: u64 = 18_446_744_073_709_551_615u64
pub const BITS: u32 = 64u32